@@ -8,18 +8,18 @@ from .base import Connection
 class MemcachedConnection(Connection):
     connection: "Client"
 
-    def get(self, key: Text):
+    def get(self, key: Text) -> bytes:
         return self.connection.get(key)
 
-    def set(self, key: Text, value: Text):
+    def set(self, key: Text, value: Text) -> bool:
         return self.connection.set(key, value)
 
     def get_many(self, keys: List[Text]) -> Dict[Text, bytes]:
         return self.connection.get_many(keys)
 
-    def set_many(self, values: Dict[Text, Text]):
+    def set_many(self, values: Dict[Text, Text]) -> List[Text]:
         failed_keys = self.connection.set_many(values)
         return list(set(values.keys()) - set(failed_keys))
 
-    def keys(self, pattern: Text) -> List[bytes]:
-        raise NotImplemented()
+    def keys(self, pattern: Text) -> List[Text]:
+        raise NotImplementedError()
