@@ -1,27 +1,23 @@
 import ast
 import zlib
 from dataclasses import dataclass
-from typing import Union, List
+from typing import Union, List, get_type_hints
 
 from data_snack.entities import Entity
 from data_snack.serializers.base import Serializer
 
 
-def _serialize(entity: Entity) -> bytes:
-    return zlib.compress(str(list(entity.__dict__.values())).encode())
-
-
 @dataclass
 class DataclassSerializer(Serializer):
     def __post_init__(self):
-        self.entity_fields = list(self.entity_type.__dataclass_fields__.keys())
+        self.entity_fields = list(get_type_hints(self.entity_type).keys())
 
     def _serialize(self, entity: Entity) -> bytes:
         entity_fields = entity.__dict__
         values = [entity_fields[field] for field in self.entity_fields]
         return zlib.compress(str(values).encode())
 
-    def serialize(self, entity: Union[Entity, List[Entity]], many: bool=False) -> Union[bytes, List[bytes]]:
+    def serialize(self, entity: Union[Entity, List[Entity]], many: bool = False) -> Union[bytes, List[bytes]]:
         return [self._serialize(e) for e in entity] if many else self._serialize(entity)
 
     def _deserialize(self, data: bytes) -> Entity:
